[![Banner](banner.png)](https://capsizegames.itch.io/ai-runner)

AI Runner official repository which houses the templates and primary client code for AI Runner.

---

## Installation

`pip install aihandler`

---

## Development setup
